==> akonadi-1.9.0.tar.bz2: akonadi-1.9.0/server/src/storage/querycache.cpp <==
/*
    Copyright (c) 2012 Volker Krause <vkrause@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
 */

#include "querycache.h"

#include <QSqlQuery>
#include <QThreadStorage>
#include <QtCore/QHash>

using namespace Akonadi;

static QThreadStorage< QHash<QString, QSqlQuery>* > g_queryCache;

static QHash<QString, QSqlQuery>* cache()
{
  if ( !g_queryCache.hasLocalData() )
    g_queryCache.setLocalData( new QHash<QString, QSqlQuery>() );
  return g_queryCache.localData();
}

bool QueryCache::contains(const QString& queryStatement)
{
  return cache()->contains( queryStatement );
}

QSqlQuery QueryCache::query(const QString& queryStatement)
{
  return cache()->value( queryStatement );
}

void QueryCache::insert(const QString& queryStatement, const QSqlQuery& query)
{
  cache()->insert( queryStatement, query );
}

==> akonadi-1.9.2.tar.bz2: akonadi-1.9.2/server/src/storage/querycache.cpp <==
/*
    Copyright (c) 2012 Volker Krause <vkrause@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
 */

#include "querycache.h"
#include "dbtype.h"
#include "datastore.h"

#include <QSqlQuery>
#include <QThreadStorage>
#include <QtCore/QHash>

using namespace Akonadi;

static QThreadStorage< QHash<QString, QSqlQuery>* > g_queryCache;

static QHash<QString, QSqlQuery>* cache()
{
  if ( !g_queryCache.hasLocalData() )
    g_queryCache.setLocalData( new QHash<QString, QSqlQuery>() );
  return g_queryCache.localData();
}

bool QueryCache::contains(const QString& queryStatement)
{
  if ( DbType::type( DataStore::self()->database() ) == DbType::Sqlite ) {
    return false;
  } else {
    return cache()->contains( queryStatement );
  }
}

QSqlQuery QueryCache::query(const QString& queryStatement)
{
  return cache()->value( queryStatement );
}

void QueryCache::insert(const QString& queryStatement, const QSqlQuery& query)
{
  if ( DbType::type( DataStore::self()->database() ) != DbType::Sqlite ) {
    cache()->insert( queryStatement, query );
  }
}
